Stan Math Library: stan::math::detail::bounded< T_y, T_low, T_high, true > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::detail::bounded< T_y, T_low, T_high, true > Struct Template Reference

`#include <check_bounded.hpp>`

## Static Public Member Functions
static bool | check (const char *function, const char *name, const T_y &y, const T_low &low, const T_high &high)

## Detailed Description

### template<typename T_y, typename T_low, typename T_high>
struct stan::math::detail::bounded< T_y, T_low, T_high, true >

Definition at line 49 of file check_bounded.hpp.

## Member Function Documentation

template<typename T_y , typename T_low , typename T_high >

static bool stan::math::detail::bounded< T_y, T_low, T_high, true >::check | ( | const char * | function,
|  | const char * | name,
|  | const T_y & | y,
|  | const T_low & | low,
|  | const T_high & | high
| ) |  |
| inlinestatic

Definition at line 50 of file check_bounded.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/err/check_bounded.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.